# Girvan Newman Algorithm to find community structure
[![Build Status](https://travis-ci.com/zhaofeng-shu33/Girvan-Newman.svg?branch=master)](https://travis-ci.com/zhaofeng-shu33/Girvan-Newman)
[![Appveyor](https://ci.appveyor.com/api/projects/status/github/zhaofeng-shu33/girvan-newman?branch=master&svg=true)](https://ci.appveyor.com/project/zhaofeng-shu33/girvan-newman)

A Girvan Newman step is defined as a couple of successive edge removes such that a new community occurs.

